@@ -1,8 +1,7 @@
-require 'benchmark'
-
 require 'active_ldap/schema'
 require 'active_ldap/entry_attribute'
 require 'active_ldap/ldap_error'
+require 'active_ldap/supported_control'
 
 module ActiveLdap
   module Adapter
@@ -19,9 +18,7 @@ module ActiveLdap
 
       @@row_even = true
 
-      attr_reader :runtime
       def initialize(configuration={})
-        @runtime = 0
         @connection = nil
         @disconnected = false
         @bound = false
@@ -36,11 +33,6 @@ module ActiveLdap
         @instrumenter = ActiveSupport::Notifications.instrumenter
       end
 
-      def reset_runtime
-        runtime, @runtime = @runtime, 0
-        runtime
-      end
-
       def connect(options={})
         host = options[:host] || @host
         method = options[:method] || @method || :plain
@@ -148,6 +140,11 @@ module ActiveLdap
         root_dse_values('namingContexts')
       end
 
+      def supported_control
+        @supported_control ||=
+          SupportedControl.new(root_dse_values("supportedControl"))
+      end
+
       def entry_attribute(object_classes)
         @entry_attributes[object_classes.uniq.sort] ||=
           EntryAttribute.new(schema, object_classes)
@@ -240,13 +237,6 @@ module ActiveLdap
         end
       end
 
-      def log_info(name, runtime_in_seconds, info=nil)
-        return unless @logger
-        return unless @logger.debug?
-        message = "LDAP: #{name} (#{'%.1f' % (runtime_in_seconds * 1000)}ms)"
-        @logger.debug(format_log_entry(message, info))
-      end
-
       private
       def ensure_port(method)
         if method == :ssl
@@ -589,7 +579,7 @@ module ActiveLdap
             @logger.error do
               _("Reconnect to server failed: %s\n" \
                 "Reconnect to server failed backtrace:\n" \
-                "%s") % [detail.exception, detail.backtrace.join("\n")]
+                "%s") % [detail.message, detail.backtrace.join("\n")]
             end
             # Do not loop if forced
             raise ConnectionError, detail.message if force
@@ -645,7 +635,8 @@ module ActiveLdap
                :scope => :base,
                :attributes => attrs,
                :limit => 1,
-               :try_reconnect => try_reconnect) do |dn, attributes|
+               :try_reconnect => try_reconnect,
+               :use_paged_results => false) do |dn, attributes|
           found_attributes = attributes
         end
         found_attributes
@@ -666,42 +657,13 @@ module ActiveLdap
       end
 
       def log(name, info=nil)
-        if block_given?
-          result = nil
-          @instrumenter.instrument(
-            "log_info.active_ldap",
-            :info => info,
-            :name => name) { result = yield }
-          result
-        else
-          log_info(name, 0, info)
-          nil
-        end
-      rescue Exception
-        log_info("#{name}: FAILED", 0,
-                 (info || {}).merge(:error => $!.class.name,
-                                    :error_message => $!.message))
-        raise
-      end
-
-      def format_log_entry(message, info=nil)
-        if ActiveLdap::Base.colorize_logging
-          if @@row_even
-            message_color, dump_color = "4;36;1", "0;1"
-          else
-            @@row_even = true
-            message_color, dump_color = "4;35;1", "0"
-          end
-          @@row_even = !@@row_even
-
-          log_entry = "  \e[#{message_color}m#{message}\e[0m"
-          log_entry << ": \e[#{dump_color}m#{info.inspect}\e[0m" if info
-          log_entry
-        else
-          log_entry = message
-          log_entry += ": #{info.inspect}" if info
-          log_entry
+        result = nil
+        payload = {:name => name}
+        payload[:info] = info if info
+        @instrumenter.instrument("log_info.active_ldap", payload) do
+          result = yield if block_given?
         end
+        result
       end
 
       def ensure_dn_string(dn)
