@@ -55,8 +55,10 @@ module ActiveLdap
           uri = construct_uri(host, port, method.ssl?)
           with_start_tls = method.start_tls?
           info = {:uri => uri, :with_start_tls => with_start_tls}
-          [log("connect", info) {method.connect(host, port)},
-           uri, with_start_tls]
+          connection = log("connect", info) do
+            method.connect(host, port)
+          end
+          [connection, uri, with_start_tls]
         end
       end
 
@@ -82,12 +84,23 @@ module ActiveLdap
       def search(options={})
         super(options) do |base, scope, filter, attrs, limit|
           begin
+            use_paged_results = options[:use_paged_results]
+            if use_paged_results or use_paged_results.nil?
+              use_paged_results = supported_control.paged_results?
+            end
             info = {
               :base => base, :scope => scope_name(scope),
               :filter => filter, :attributes => attrs, :limit => limit,
             }
-            execute(:search_with_limit,
-                    info, base, scope, filter, attrs, limit) do |entry|
+            options = {
+              :base              => base,
+              :scope             => scope,
+              :filter            => filter,
+              :attributes        => attrs,
+              :limit             => limit,
+              :use_paged_results => use_paged_results
+            }
+            execute(:search_full, info, options) do |entry|
               attributes = {}
               entry.attrs.each do |attr|
                 value = entry.vals(attr)
