@@ -292,9 +292,6 @@ module ActiveLdap
       end
     end
 
-    cattr_accessor :colorize_logging, :instance_writer => false
-    @@colorize_logging = true
-
     VALID_LDAP_MAPPING_OPTIONS = [:dn_attribute, :prefix, :scope,
                                   :classes, :recommended_classes,
                                   :excluded_classes, :sort_by, :order]
